@@ -1,18 +1,22 @@
+use preserves_schema::Codec;
+
 use std::path::PathBuf;
 use std::sync::Arc;
 
 use structopt::StructOpt;
 
 use syndicate::actor::*;
-use syndicate::convert::from_io_value;
 use syndicate::dataspace::*;
+use syndicate::enclose;
 use syndicate::relay;
 use syndicate::schemas::service;
 use syndicate::schemas::transport_address;
 
 use syndicate::value::NestedValue;
 
+mod dependencies;
 mod gatekeeper;
+mod language;
 mod protocol;
 mod services;
 
@@ -20,6 +24,7 @@ mod schemas {
     include!(concat!(env!("OUT_DIR"), "/src/schemas/mod.rs"));
 }
 
+use language::language;
 use schemas::internal_services;
 
 #[derive(Clone, StructOpt)]
@@ -76,12 +81,11 @@ async fn main() -> Result<(), Box<dyn std::error::Error>> {
 
         if config.inferior {
             tracing::info!("inferior server instance");
-            let root_ds = Arc::clone(&root_ds);
-            t.spawn(syndicate::name!("parent"), move |t| protocol::run_io_relay(
+            t.spawn(syndicate::name!("parent"), enclose!((root_ds) move |t| protocol::run_io_relay(
                 t,
                 relay::Input::Bytes(Box::pin(tokio::io::stdin())),
                 relay::Output::Bytes(Box::pin(tokio::io::stdout())),
-                root_ds));
+                root_ds)));
         }
 
         let server_config_ds = Cap::new(&t.create(Dataspace::new()));
@@ -91,49 +95,49 @@ async fn main() -> Result<(), Box<dyn std::error::Error>> {
         gatekeeper::bind(t, &root_ds, AnyValue::new("server-config"), [0; 16],
                          Arc::clone(&server_config_ds));
 
-        let gateway = Cap::guard(&t.create(
+        let gateway = Cap::guard(Arc::clone(&language().syndicate), t.create(
             syndicate::entity(Arc::clone(&root_ds)).on_asserted(gatekeeper::handle_resolve)));
 
+        dependencies::boot(t, Arc::clone(&server_config_ds));
+        services::config_watcher::on_demand(t, Arc::clone(&server_config_ds));
+        services::daemon::on_demand(t, Arc::clone(&server_config_ds), Arc::clone(&root_ds));
         services::debt_reporter::on_demand(t, Arc::clone(&server_config_ds));
+        services::milestone::on_demand(t, Arc::clone(&server_config_ds));
         services::tcp_relay_listener::on_demand(t, Arc::clone(&server_config_ds), Arc::clone(&gateway));
         services::unix_relay_listener::on_demand(t, Arc::clone(&server_config_ds), Arc::clone(&gateway));
-        services::config_watcher::on_demand(t, Arc::clone(&server_config_ds));
 
         if config.debt_reporter {
-            server_config_ds.assert(t, &service::RequireService {
-                service_name: from_io_value(&internal_services::DebtReporter)?,
+            server_config_ds.assert(t, language(), &service::RunService {
+                service_name: language().unparse(&internal_services::DebtReporter),
             });
         }
 
         for port in config.ports.clone() {
-            server_config_ds.assert(t, &service::RequireService {
-                service_name: from_io_value(
-                    &internal_services::TcpRelayListener {
-                        addr: transport_address::Tcp {
-                            host: "0.0.0.0".to_owned(),
-                            port: (port as i32).into(),
-                        }
-                    })?,
+            server_config_ds.assert(t, language(), &service::RunService {
+                service_name: language().unparse(&internal_services::TcpRelayListener {
+                    addr: transport_address::Tcp {
+                        host: "0.0.0.0".to_owned(),
+                        port: (port as i32).into(),
+                    }
+                }),
             });
         }
 
         for path in config.sockets.clone() {
-            server_config_ds.assert(t, &service::RequireService {
-                service_name: from_io_value(
-                    &internal_services::UnixRelayListener {
-                        addr: transport_address::Unix {
-                            path: path.to_str().expect("representable UnixListener path").to_owned(),
-                        }
-                    })?,
+            server_config_ds.assert(t, language(), &service::RunService {
+                service_name: language().unparse(&internal_services::UnixRelayListener {
+                    addr: transport_address::Unix {
+                        path: path.to_str().expect("representable UnixListener path").to_owned(),
+                    }
+                }),
             });
         }
 
         for path in config.config.clone() {
-            server_config_ds.assert(t, &service::RequireService {
-                service_name: from_io_value(
-                    &internal_services::ConfigWatcher {
-                        path: path.to_str().expect("representable ConfigWatcher path").to_owned(),
-                    })?,
+            server_config_ds.assert(t, language(), &service::RunService {
+                service_name: language().unparse(&internal_services::ConfigWatcher {
+                    path: path.to_str().expect("representable ConfigWatcher path").to_owned(),
+                }),
             });
         }
 
