@@ -3,7 +3,8 @@ use notify::Watcher;
 use notify::RecursiveMode;
 use notify::watcher;
 
-use std::convert::TryFrom;
+use preserves_schema::Codec;
+
 use std::fs;
 use std::future;
 use std::io;
@@ -14,9 +15,7 @@ use std::thread;
 use std::time::Duration;
 
 use syndicate::actor::*;
-use syndicate::convert::*;
-use syndicate::during::entity;
-use syndicate::schemas::dataspace::Observe;
+use syndicate::enclose;
 use syndicate::value::BinarySource;
 use syndicate::value::IOBinarySource;
 use syndicate::value::Map;
@@ -26,26 +25,19 @@ use syndicate::value::Reader;
 use syndicate::value::Set;
 use syndicate::value::ViaCodec;
 
+use crate::language::language;
 use crate::schemas::internal_services;
 
+use syndicate_macros::during;
+
 pub fn on_demand(t: &mut Activation, ds: Arc<Cap>) {
     t.spawn(syndicate::name!("on_demand", module = module_path!()), move |t| {
-        let monitor = entity(())
-            .on_asserted_facet({
-                let ds = Arc::clone(&ds);
-                move |_, t, captures| {
-                    let ds = Arc::clone(&ds);
-                    t.spawn_link(syndicate::name!(parent: None, "config", spec = ?captures),
-                                 |t| run(t, ds, captures));
-                    Ok(())
-                }
-            })
-            .create_cap(t);
-        ds.assert(t, &Observe {
-            pattern: syndicate_macros::pattern!{<require-service $(<config-watcher _>)>},
-            observer: monitor,
-        });
-        Ok(())
+        Ok(during!(t, ds, language(), <run-service $spec: internal_services::ConfigWatcher>,
+                   |t: &mut Activation| {
+                       t.spawn_link(syndicate::name!(parent: None, "config", spec = ?spec),
+                                    enclose!((ds) |t| run(t, ds, spec)));
+                       Ok(())
+                   }))
     });
 }
 
@@ -57,13 +49,13 @@ fn assertions_at_existing_file(t: &mut Activation, ds: &Arc<Cap>, path: &PathBuf
     let mut handles = Set::new();
     let fh = fs::File::open(path)?;
     let mut src = IOBinarySource::new(fh);
-    let mut r = src.text::<_, AnyValue, _>(ViaCodec::new(NoEmbeddedDomainCodec));
+    let mut r = src.text::<AnyValue, _>(ViaCodec::new(NoEmbeddedDomainCodec));
     let mut values = Vec::new();
-    while let Some(value) = Reader::<_, AnyValue>::next(&mut r, true)? {
+    while let Some(value) = Reader::<AnyValue>::next(&mut r, true)? {
         values.push(value);
     }
     for value in values.into_iter() {
-        if let Some(handle) = ds.assert(t, value.clone()) {
+        if let Some(handle) = ds.assert(t, &(), &value) {
             handles.insert(handle);
         }
     }
@@ -144,12 +136,10 @@ fn initial_scan(
     }
 }
 
-fn run(t: &mut Activation, ds: Arc<Cap>, captures: AnyValue) -> ActorResult {
-    let spec = internal_services::ConfigWatcher::try_from(&from_any_value(
-        &captures.value().to_sequence()?[0])?)?;
+fn run(t: &mut Activation, ds: Arc<Cap>, spec: internal_services::ConfigWatcher) -> ActorResult {
     {
-        let spec = from_io_value(&spec)?;
-        ds.assert(t, syndicate_macros::template!("<service-running =spec>"));
+        let spec = language().unparse(&spec);
+        ds.assert(t, &(), &syndicate_macros::template!("<service-running =spec>"));
     }
     let path = fs::canonicalize(spec.path)?;
 
