@@ -1,41 +1,31 @@
-use std::convert::TryFrom;
+use preserves_schema::Codec;
+
 use std::io;
 use std::path::PathBuf;
 use std::sync::Arc;
 
 use syndicate::actor::*;
-use syndicate::convert::*;
-use syndicate::during::entity;
+use syndicate::enclose;
 use syndicate::error::Error;
 use syndicate::relay;
-use syndicate::schemas::dataspace::Observe;
-use syndicate::value::NestedValue;
 
 use tokio::net::UnixListener;
 use tokio::net::UnixStream;
 
+use crate::language::language;
 use crate::protocol::run_connection;
 use crate::schemas::internal_services;
 
+use syndicate_macros::during;
+
 pub fn on_demand(t: &mut Activation, ds: Arc<Cap>, gateway: Arc<Cap>) {
     t.spawn(syndicate::name!("on_demand", module = module_path!()), move |t| {
-        let monitor = entity(())
-            .on_asserted_facet({
-                let ds = Arc::clone(&ds);
-                move |_, t, captures| {
-                    let ds = Arc::clone(&ds);
-                    let gateway = Arc::clone(&gateway);
-                    t.spawn_link(syndicate::name!(parent: None, "relay", addr = ?captures),
-                                 |t| run(t, ds, gateway, captures));
-                    Ok(())
-                }
-            })
-            .create_cap(t);
-        ds.assert(t, &Observe {
-            pattern: syndicate_macros::pattern!{<require-service $(<relay-listener <unix _>>)>},
-            observer: monitor,
-        });
-        Ok(())
+        Ok(during!(t, ds, language(), <run-service $spec: internal_services::UnixRelayListener>,
+                   |t: &mut Activation| {
+                       t.spawn_link(syndicate::name!(parent: None, "relay", addr = ?spec),
+                                    enclose!((ds, gateway) |t| run(t, ds, gateway, spec)));
+                       Ok(())
+                   }))
     });
 }
 
@@ -43,14 +33,12 @@ fn run(
     t: &'_ mut Activation,
     ds: Arc<Cap>,
     gateway: Arc<Cap>,
-    captures: AnyValue,
+    spec: internal_services::UnixRelayListener,
 ) -> ActorResult {
-    let spec = internal_services::UnixRelayListener::try_from(&from_any_value(
-        &captures.value().to_sequence()?[0])?)?;
     let path_str = spec.addr.path.clone();
     {
-        let spec = from_io_value(&spec)?;
-        ds.assert(t, syndicate_macros::template!("<service-running =spec>"));
+        let spec = language().unparse(&spec);
+        ds.assert(t, &(), &syndicate_macros::template!("<service-running =spec>"));
     }
     let parent_span = tracing::Span::current();
     t.linked_task(syndicate::name!("listener"), async move {
@@ -59,12 +47,11 @@ fn run(
         loop {
             let (stream, _addr) = listener.accept().await?;
             let peer = stream.peer_cred()?;
-            let gateway = Arc::clone(&gateway);
             Actor::new().boot(
                 syndicate::name!(parent: parent_span.clone(), "conn",
                                  pid = ?peer.pid().unwrap_or(-1),
                                  uid = peer.uid()),
-                |t| Ok(t.linked_task(
+                enclose!((gateway) |t| Ok(t.linked_task(
                     tracing::Span::current(),
                     {
                         let facet = t.facet.clone();
@@ -76,7 +63,7 @@ fn run(
                                            relay::Output::Bytes(Box::pin(o)),
                                            gateway)
                         }
-                    })));
+                    }))));
         }
     });
     Ok(())
